package com.chinaitop.agile.controller;

import java.io.OutputStream;
import java.net.URLEncoder;
import java.util.List;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.chinaitop.agile.model.Loginfo;
import com.chinaitop.agile.service.LoginfoService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping(value="/agile/crkrz")
@Api(value= "LoginfoController", description = "出入库日志")
public class LoginfoController {

	@Resource
	private LoginfoService loginfoService;

	@RequestMapping(value="/getList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="出入库日志列表", notes = "支持分页")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
			@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
			@ApiImplicitParam(name = "rzlx", value = "日志类型", paramType = "query"),
			@ApiImplicitParam(name="gnmc", value="模块名称", paramType="query"),
			@ApiImplicitParam(name="fwstartTime", value="访问起始时间", paramType="query"),
			@ApiImplicitParam(name="fwendDate", value="访问终止时间", paramType="query"),
			@ApiImplicitParam(name="yhmc", value="用户名称", paramType="query")
	})
	public PageInfo<Loginfo> getList(Integer pageNum, Integer pageSize, String rzlx, String gnmc,
			String fwstartTime, String fwendDate, String yhmc) {
		List<Loginfo> list = null;
		try {
			if (pageNum != null && pageSize != null) {
				PageHelper.startPage(pageNum, pageSize);
			}
			list = loginfoService.quaryList(rzlx, gnmc, fwstartTime, fwendDate, yhmc);
		} catch (Exception e) {
			e.printStackTrace();
		}
		PageInfo<Loginfo> pageInfo = new PageInfo<>(list);
		return pageInfo;
	}
	
	@RequestMapping(value="/exportCrkLoginOld", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="条件导出出入库日志", notes = "条件查询和列表一致(Excel格式)")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
		@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
		@ApiImplicitParam(name = "rzlx", value = "日志类型(0:登录日志,1:功能操作日志)", paramType = "query"),
		@ApiImplicitParam(name="gnmc", value="模块名称", paramType="query"),
		@ApiImplicitParam(name="fwstartTime", value="访问起始时间", paramType="query"),
		@ApiImplicitParam(name="fwendDate", value="访问终止时间", paramType="query"),
		@ApiImplicitParam(name="yhmc", value="用户名称", paramType="query")
	})
	public void exportCrkLoginOld(HttpServletResponse response, HttpServletRequest request, 
			Integer pageNum, Integer pageSize, String rzlx, String gnmc, String fwstartTime, String fwendDate, String yhmc){
		List<Loginfo> list = null;
		try {
			if (pageNum != null && pageSize != null) {
				PageHelper.startPage(pageNum, pageSize);
			}
			list = loginfoService.quaryList(rzlx, gnmc, fwstartTime, fwendDate, yhmc);
			HSSFWorkbook workbook = loginfoService.exportCrkLogin(list, rzlx);
			String fileName = "";
			if ("0".equals(rzlx)) {
				fileName = "出入库系统登录日志";
			} else {
				fileName = "出入库系统功能操作日志";
			}
			// 获取输出流
			OutputStream os = response.getOutputStream();
			// 重置输出流
			response.reset();
			// 设定输出文件头
			response.setHeader("Content-disposition", "attachment; filename=" + new String(fileName.getBytes("GB2312"), "8859_1") + ".xlsx");
			//name属性设置和跨服访问有关
			response.setHeader("Access-Control-Allow-Origin", "*");
			// 定义输出内容类型
			response.setContentType("application/vnd.ms-excel;charset=gb2312");
			workbook.write(os);
			//关闭流
			os.close();
			return;
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
	
	@RequestMapping(value="/exportCrkLogin", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
	@ApiOperation(value="条件导出出入库日志", notes = "条件查询和列表一致(csv格式),最多10W条")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
		@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
		@ApiImplicitParam(name = "rzlx", value = "日志类型(0:登录日志,1:功能操作日志)", required=true, paramType = "query"),
		@ApiImplicitParam(name="gnmc", value="模块名称", paramType="query"),
		@ApiImplicitParam(name="fwstartTime", value="访问起始时间", paramType="query"),
		@ApiImplicitParam(name="fwendDate", value="访问终止时间", paramType="query"),
		@ApiImplicitParam(name="yhmc", value="用户名称", paramType="query")
	})
	public void exportCrkLogin(HttpServletResponse response, HttpServletRequest request,
			Integer pageNum, Integer pageSize, String rzlx, String gnmc, String fwstartTime, String fwendDate, String yhmc){
		List<Loginfo> list = null;
		try {
			if (null == pageNum) {
				pageNum = 1;
			}
			if (null == pageSize) {
				pageSize = 100000;
			}
			if (pageNum*pageSize>100000) {
				pageNum = 1;
				pageSize = 100000;
			}
			PageHelper.startPage(pageNum, pageSize);
			list = loginfoService.quaryList(rzlx, gnmc, fwstartTime, fwendDate, yhmc);
			String res = loginfoService.exportCsv(list, rzlx);
			String fileName = "";
			if ("0".equals(rzlx)) {
				fileName = "出入库系统登录日志.csv";
			} else {
				fileName = "出入库系统功能操作日志.csv";
			}
			// 获取输出流
			OutputStream os = response.getOutputStream();
			// 读取字符编码
			String utf = "UTF-8";
			// 重置输出流
			response.reset();
			// 设置响应
			response.setContentType("application/ms-txt.numberformat:@");
			response.setCharacterEncoding(utf);
			response.setHeader("Pragma", "public");
			response.setHeader("Cache-Control", "max-age=30");
			response.setHeader("Content-Disposition", "attachment; filename=" + URLEncoder.encode(fileName, utf));

			// 写出响应
			os.write(res.getBytes("UTF-8"));
			os.flush();
			os.close();
			return;
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
}
