package com.chinaitop.agile.service.impl;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.apache.commons.lang3.StringUtils;
import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFCellStyle;
import org.apache.poi.hssf.usermodel.HSSFFont;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.ss.util.CellRangeAddress;
import org.springframework.stereotype.Service;

import com.chinaitop.agile.mapper.LoginfoMapper;
import com.chinaitop.agile.model.Loginfo;
import com.chinaitop.agile.service.LoginfoService;
import com.chinaitop.agile.utils.ParameterUtil;


@Service
public class LoginfoServiceImpl implements LoginfoService {

	@Resource
	private LoginfoMapper loginfoMapper;

	@Override
	public List<Loginfo> quaryList(String rzlx, String gnmc, String fwstartTime, String fwendDate, String yhmc) throws Exception {
		Map<String, Object> map = new HashMap<>();
		if (StringUtils.isNotBlank(rzlx)) {
			map.put("rzlx", rzlx);
		}
		if (StringUtils.isNotBlank(gnmc)) {
			map.put("gnmc", "%"+gnmc+"%");
		}
		if (StringUtils.isNotBlank(fwstartTime)) {
			map.put("fwstartTime", ParameterUtil.string2datetime(fwstartTime));
		}
		if (StringUtils.isNotBlank(fwendDate)) {
			map.put("fwendDate", ParameterUtil.string2datetime(fwendDate));
		}
		if (StringUtils.isNotBlank(yhmc)) {
			map.put("yhmc", "%"+yhmc+"%");
		}
		return loginfoMapper.quaryList(map);
	}

	@Override
	public HSSFWorkbook exportCrkLogin(List<Loginfo> list, String rzlx) throws Exception {
		HSSFWorkbook wb = new HSSFWorkbook();
		String name = "";
		if ("0".equals(rzlx)) {
			name = "出入库系统登录日志";
		} else {
			name = "出入库系统功能操作日志";
		}
		HSSFSheet sheet = wb.createSheet(name);
		// 起始行、结束行、起始列、结束列
		CellRangeAddress rangeAddress = new CellRangeAddress(0,0,0,0);
		CellRangeAddress rangeAddress1 = new CellRangeAddress(0,0,1,1);
		CellRangeAddress rangeAddress2 = new CellRangeAddress(0,0,2,2);
		CellRangeAddress rangeAddress3 = new CellRangeAddress(0,0,3,3);
		CellRangeAddress rangeAddress4 = new CellRangeAddress(0,0,4,4);
		sheet.addMergedRegion(rangeAddress);
		sheet.addMergedRegion(rangeAddress1);
		sheet.addMergedRegion(rangeAddress2);
		sheet.addMergedRegion(rangeAddress3);
		sheet.addMergedRegion(rangeAddress4);
		sheet.setColumnWidth(0, 10*256);
		sheet.setColumnWidth(1, 20*256);
		sheet.setColumnWidth(2, 30*256);
		sheet.setColumnWidth(3, 40*256);
		sheet.setColumnWidth(4, 40*256);

		HSSFCellStyle contentStyle = wb.createCellStyle();
		HSSFFont contentFont = wb.createFont();
		contentFont.setFontName("黑体");
		contentFont.setFontHeightInPoints((short) 12);
		contentStyle.setFont(contentFont);
		contentStyle.setBorderBottom(HSSFCellStyle.BORDER_THIN); //下边框
		contentStyle.setBorderLeft(HSSFCellStyle.BORDER_THIN);//左边框
		contentStyle.setBorderTop(HSSFCellStyle.BORDER_THIN);//上边框
		contentStyle.setBorderRight(HSSFCellStyle.BORDER_THIN);
		contentStyle.setVerticalAlignment(HSSFCellStyle.VERTICAL_CENTER);
		contentStyle.setAlignment(HSSFCellStyle.ALIGN_CENTER);
		
		HSSFCellStyle titleStyle = wb.createCellStyle();
		HSSFFont titleFont = wb.createFont();
		titleFont.setFontName("宋体");
		titleFont.setFontHeightInPoints((short) 12);
		titleStyle.setFont(titleFont);
		titleStyle.setBorderBottom(HSSFCellStyle.BORDER_THIN); //下边框
		titleStyle.setBorderLeft(HSSFCellStyle.BORDER_THIN);//左边框
		titleStyle.setBorderTop(HSSFCellStyle.BORDER_THIN);//上边框
		titleStyle.setBorderRight(HSSFCellStyle.BORDER_THIN);//右边框
		titleStyle.setAlignment(HSSFCellStyle.ALIGN_CENTER);

		//第一行：标题行
		HSSFRow sheetRow0 = sheet.createRow(0);
		HSSFCell cell0 = sheetRow0.createCell(0);
		HSSFCell cell1 = sheetRow0.createCell(1);
		HSSFCell cell2 = sheetRow0.createCell(2);
		HSSFCell cell3 = sheetRow0.createCell(3);
		HSSFCell cell4 = sheetRow0.createCell(4);
		cell0.setCellStyle(contentStyle);
		cell1.setCellStyle(contentStyle);
		cell2.setCellStyle(contentStyle);
		cell3.setCellStyle(contentStyle);
		cell4.setCellStyle(contentStyle);
		cell0.setCellValue("序号");
		if ("0".equals(rzlx)) {
			cell1.setCellValue("访问用户账号");
			cell2.setCellValue("用户名称");
			cell3.setCellValue("用户设备IP");
			cell4.setCellValue("登陆时间");
		} else {
			cell1.setCellValue("页面名称");
			cell2.setCellValue("访问用户名称");
			cell3.setCellValue("用户设备IP");
			cell4.setCellValue("访问页面时间");
		}

		//数据行
		int rowNum = 0;
		Integer xh=1;
		Loginfo logInfo = null;
		for(int i=0; i < list.size(); i++){
			logInfo = list.get(i);
			HSSFRow hssfRow = sheet.createRow(++rowNum);
			HSSFCell hssfCell1 = hssfRow.createCell(0);
			HSSFCell hssfCell2 = hssfRow.createCell(1);
			HSSFCell hssfCell3 = hssfRow.createCell(2);
			HSSFCell hssfCell4 = hssfRow.createCell(3);
			HSSFCell hssfCell5 = hssfRow.createCell(4);

			hssfCell1.setCellStyle(titleStyle);
			hssfCell2.setCellStyle(titleStyle);
			hssfCell3.setCellStyle(titleStyle);
			hssfCell4.setCellStyle(titleStyle);
			hssfCell5.setCellStyle(titleStyle);

			hssfCell1.setCellValue(xh);
			if ("0".equals(rzlx)) {
				hssfCell2.setCellValue(logInfo.getYhzh());
				hssfCell3.setCellValue(logInfo.getYhmc());
				hssfCell4.setCellValue(logInfo.getYhip());
				hssfCell5.setCellValue(logInfo.getFwsj());
			} else {
				hssfCell2.setCellValue(logInfo.getGnmc());
				hssfCell3.setCellValue(logInfo.getYhmc());
				hssfCell4.setCellValue(logInfo.getYhip());
				hssfCell5.setCellValue(logInfo.getFwsj());
			}
			++xh;
		}
		return wb;
	}

	@Override
	public String exportCsv(List<Loginfo> list, String rzlx) throws Exception {
		// 保证线程安全
		StringBuffer buf = new StringBuffer();

		//设备每列头部信息
		String header = null;
		if ("0".equals(rzlx)) {//登录日志
			header = "序号,系统名称,粮库名称,访问用户账号,用户名称,用户设备IP,登陆时间";
		} else {
			header = "序号,系统名称,粮库名称,页面名称,访问用户名称,用户设备IP,访问页面时间";
		}
		String[] csvHeader = header.split(",");
		if (list.size() > 0) {
			// 组装表头
			for (String title : csvHeader) {
				buf.append(title).append(",");
			}
			buf.append(System.lineSeparator());

			// 组装数据
			//这块主要是在导出csv文件时，如何数据的内容当中包含逗号时，进行！替换。否则解析时会导致数据分割报错。不是自己真是数据。
			//String replace = data.get(key).toString().replaceAll(",", "!");
			//StringBuffer append = buf.append(data.get(key).toString().replaceAll(",", "!")).append(",");
			if (null != list && list.size() > 0) {
				Loginfo l = null;
				for (int i = 0; i < list.size(); i++) {
					l = list.get(i);
					buf.append(i+1).append(",");
					if ("0".equals(rzlx)) {//登录日志
						//时间值的前后加'\t'可以保证文件导出后打开后时间显示正常
						buf.append("天津市智能粮库出入库系统").append(",").append(l.getLkmc()).append(",").append(l.getYhzh()).append(",").append(l.getYhmc()).append(",").append(l.getYhip()).append(",").append('\t').append(l.getFwsj()).append('\t').append(",");
					} else {
						buf.append("天津市智能粮库出入库系统").append(",").append(l.getLkmc()).append(",").append(l.getGnmc()).append(",").append(l.getYhmc()).append(",").append(l.getYhip()).append(",").append('\t').append(l.getFwsj()).append('\t').append(",");
					}
					buf.append(System.lineSeparator());
				}
			}
		}

		return buf.toString();
	}
}
